@@ -14,6 +14,7 @@
 
 from tensorflow import keras
 
+from keras_tuner import utils
 from keras_tuner.engine.hyperparameters import hp_types
 from keras_tuner.engine.hyperparameters.hp_types import Boolean
 from keras_tuner.engine.hyperparameters.hp_types import Choice
@@ -32,8 +33,8 @@ ALL_CLASSES = {cls.__name__: cls for cls in OBJECTS}
 
 
 def deserialize(config):
-    return keras.utils.deserialize_keras_object(config, module_objects=ALL_CLASSES)
+    return utils.deserialize_keras_object(config, module_objects=ALL_CLASSES)
 
 
 def serialize(obj):
-    return keras.utils.serialize_keras_object(obj)
+    return utils.serialize_keras_object(obj)
